/*
 * Misc image conversion routines
 * most functionality is exported to the public API, see avcodec.h
 *
 * Copyright (c) 2008 Vitor Sessak
 *
 * This file is part of FFmpeg.
 *
 * FFmpeg is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * FFmpeg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with FFmpeg; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

#ifndef AVCODEC_IMGCONVERT_H
#define AVCODEC_IMGCONVERT_H

#include <stdint.h>
#include "avcodec.h"

// changed by Greg Wolfe, Eastman Kodak Company
// FF_COLOR_* and FF_PIXEL_* moved here from imgconvert.c
#define FF_COLOR_RGB      0 /**< RGB color space */
#define FF_COLOR_GRAY     1 /**< gray color space */
#define FF_COLOR_YUV      2 /**< YUV color space. 16 <= Y <= 235, 16 <= U, V <= 240 */
#define FF_COLOR_YUV_JPEG 3 /**< YUV color space. 0 <= Y <= 255, 0 <= U, V <= 255 */

#define FF_PIXEL_PLANAR   0 /**< each channel has one component in AVPicture */
#define FF_PIXEL_PACKED   1 /**< only one components containing all the channels */
#define FF_PIXEL_PALETTE  2  /**< one components containing indexes for a palette */

int ff_fill_linesize(AVPicture *picture, int pix_fmt, int width);

int ff_fill_pointer(AVPicture *picture, uint8_t *ptr, int pix_fmt, int height);

int ff_get_plane_bytewidth(enum PixelFormat pix_fmt, int width, int plane);

int ff_set_systematic_pal(uint32_t pal[256], enum PixelFormat pix_fmt);

int img_convert(AVPicture *dst, int dst_pix_fmt, const AVPicture *src,
                int src_pix_fmt, int src_width, int src_height);

// added by Greg Wolfe, Eastman Kodak Company
// Return PixFmtInfo[pix_fmt].color_type (FF_COLOR_*).
int avcodec_get_color_type(int pix_fmt);

// Return PixFmtInfo[pix_fmt].pixel_type (FF_PIXEL_*).
int avcodec_get_pixel_type(int pix_fmt);

// Return PixFmtInfo[pix_fmt].nb_channels.  Note that this does not always mean
// what you think it means ("... INCONCEIVABLE!").  Planar YUV formats have 3
// channels, but packed YUV formats usually have only 1 channel.  On the other
// hand, packed RGB formats have 3 channels.  Go figure ....
int avcodec_get_nb_channels(int pix_fmt);

// Return PixFmtInfo[pix_fmt].depth (bit depth of the color components).
int avcodec_get_bit_depth(int pix_fmt);

#endif /* AVCODEC_IMGCONVERT_H */
